package com.ruoyi.project.mapper;

import java.util.HashMap;
import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.project.domain.TrsResultsLog;
import com.ruoyi.project.domain.TrsResultsLogAdmin;

/**
 * 审校日志Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface TrsResultsLogMapper 
{
    /**
     * 查询审校日志
     * 
     * @param id 审校日志主键
     * @return 审校日志
     */
    public TrsResultsLog selectTrsResultsLogById(Long id);

    /**
     * 查询审校日志列表
     * 
     * @param trsResultsLog 审校日志
     * @return 审校日志集合
     */
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TrsResultsLog> selectTrsResultsLogList(TrsResultsLog trsResultsLog);

    /**
     * 查询审校日志列表
     *
     * @param trsResultsLog 审校日志
     * @return 审校日志集合
     */
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TrsResultsLogAdmin> selectTrsResultsLogExportList(TrsResultsLog trsResultsLog);

    /**
     * 新增审校日志
     * 
     * @param trsResultsLog 审校日志
     * @return 结果
     */
    public int insertTrsResultsLog(TrsResultsLog trsResultsLog);

    /**
     * 修改审校日志
     * 
     * @param trsResultsLog 审校日志
     * @return 结果
     */
    public int updateTrsResultsLog(TrsResultsLog trsResultsLog);

    /**
     * 删除审校日志
     * 
     * @param id 审校日志主键
     * @return 结果
     */
    public int deleteTrsResultsLogById(Long id);

    /**
     * 批量删除审校日志
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTrsResultsLogByIds(String[] ids);
}
